[PATCH 2/2][CRIS/CRISv32] Consistent names for cris/crisv32_elf_greg_t

Ricard Wanderlof ricard.wanderlof@axis.com
Tue Sep 3 14:17:00 GMT 2013


This is just a cosmetic change to get consistent names for
elf_greg_t/crisv32_elf_greg_t in cris-tdep.c . Compile-time tested, then
tested the result by running the resulting gdb against gdbserver running
on a target system.

Patch included inline for review and as attachement for use.


Signed-off-by: Ricard Wanderlof <ricardw@axis.com>


2013-09-03  Ricard Wanderlof  <ricardw@axis.com>

 	* cris-tdep.c (cris_elf_greg_t): Rename from elf_greg_t.


diff --git a/gdb/cris-tdep.c b/gdb/cris-tdep.c
index 80ab1b8..1b0e3cd 100644
--- a/gdb/cris-tdep.c
+++ b/gdb/cris-tdep.c
@@ -3819,25 +3819,25 @@ cris_delayed_get_disassembler (bfd_vma addr, struct disassemble_info *info)
     return print_insn (addr, info);
   }

-/* Copied from <asm/elf.h>.  */
-typedef unsigned char elf_greg_t[4];
+/* Originally from <asm/elf.h>.  */
+typedef unsigned char cris_elf_greg_t[4];

   /* Same as user_regs_struct struct in <asm/user.h>.  */
   #define CRISV10_ELF_NGREG 35
-typedef elf_greg_t elf_gregset_t[CRISV10_ELF_NGREG];
+typedef cris_elf_greg_t cris_elf_gregset_t[CRISV10_ELF_NGREG];

   #define CRISV32_ELF_NGREG 32
-typedef elf_greg_t crisv32_elf_gregset_t[CRISV32_ELF_NGREG];
+typedef cris_elf_greg_t crisv32_elf_gregset_t[CRISV32_ELF_NGREG];

 /* Unpack an elf_gregset_t into GDB's register cache.  */

   static void
-cris_supply_gregset (struct regcache *regcache, elf_gregset_t *gregsetp)
+cris_supply_gregset (struct regcache *regcache, cris_elf_gregset_t *gregsetp)
   {
     struct gdbarch *gdbarch = get_regcache_arch (regcache);
     struct gdbarch_tdep *tdep = gdbarch_tdep (gdbarch);
     int i;
-  elf_greg_t *regp = *gregsetp;
+  cris_elf_greg_t *regp = *gregsetp;
     static char zerobuf[4] = {0};

     /* The kernel dumps all 32 registers as unsigned longs, but supply_register
@@ -3868,12 +3868,12 @@ fetch_core_registers (struct regcache *regcache,
   		      char *core_reg_sect, unsigned core_reg_size,
                         int which, CORE_ADDR reg_addr)
   {
-  elf_gregset_t gregset;
+  cris_elf_gregset_t gregset;

     switch (which)
       {
       case 0:
-      if (core_reg_size != sizeof (elf_gregset_t)
+      if (core_reg_size != sizeof (cris_elf_gregset_t)
   	  && core_reg_size != sizeof (crisv32_elf_gregset_t))
           {
             warning (_("wrong size gregset struct in core file"));
@@ -3819,25 +3819,25 @@ cris_delayed_get_disassembler (bfd_vma addr, struct disassemble_info *info)

-/* Unpack an elf_gregset_t into GDB's register cache.  */
+/* Unpack a cris_elf_gregset_t into GDB's register cache.  */

   static void


/Ricard
-- 
Ricard Wolf Wanderlöf                           ricardw(at)axis.com
Axis Communications AB, Lund, Sweden            www.axis.com
Phone +46 46 272 2016                           Fax +46 46 13 61 30
-------------- next part --------------
A non-text attachment was scrubbed...
Name: cris-head-cleanup-elf_greg_t.patch
Type: text/x-diff
Size: 1959 bytes
Desc: patch file.patch
URL: <http://sourceware.org/pipermail/gdb-patches/attachments/20130903/11bd4a73/attachment.bin>


More information about the Gdb-patches mailing list